@@ -259,7 +259,15 @@ def channel_send(logger, channel, message):
 class GSPeerConnectionBroadcasterUniversalNew:
 
     @classmethod
-    async def create(cls, gsdbs, target, videostream=True, addChannel=None, oncommand=None, videotrack=None):
+    async def create(cls,
+                     gsdbs,
+                     target,
+                     videostream=True,
+                     addChannel=None,
+                     oncommand=None,
+                     videotrack=None,
+                     signalingserver=None
+                     ):
         self = GSPeerConnectionBroadcasterUniversalNew()
         self.addChannel = addChannel
         self.rtconfiList = []
@@ -268,6 +276,8 @@ class GSPeerConnectionBroadcasterUniversalNew:
         self.videostream = videostream
         self.oncommand = oncommand
         self.videotrack = videotrack
+        self.signalingserver = signalingserver
+
         if self.gsdbs.credentials["stunenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
         if self.gsdbs.credentials["turnenable"]:
@@ -395,19 +405,26 @@ class GSPeerConnectionBroadcasterUniversalNew:
 
         connectURL = ""
 
-        if "localhost" in self.gsdbs.credentials["signalserver"]:
-            connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
+        if self.signalingserver is not None:
+            connectURL = self.signalingserver
+
         else:
-            connectURL = self.gsdbs.credentials["signalserver"]
+            if "localhost" in self.gsdbs.credentials["signalserver"]:
+                connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
+            else:
+                connectURL = self.gsdbs.credentials["signalserver"]
 
         await self.sio.connect(
             f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}&target={self.target}&terminator=true')
         await self.sio.wait()
 
 
-def createTerminatorView(gsdbs, aioqueue: asyncio.Queue, target):
+def createTerminatorView(gsdbs, aioqueue: asyncio.Queue, target, signalingserver=None
+                         ):
     return asyncio.gather(checkTerminatorQueue(aioqueue),
                           GSPeerConnectionBroadcasterUniversalNew.create(gsdbs=gsdbs,
                                                                          target=target + "terminatorview",
                                                                          videostream=False,
-                                                                         videotrack=True))
+                                                                         videotrack=True,
+                                                                         signalingserver=signalingserver
+                                                                         ))
